Chaco Sine Plot Example
===============================================================================

:download:`sine_plot.enaml <../../../examples/chaco/sine_plot.enaml>`

:download:`sine_plot.py <../../../examples/chaco/sine_plot.py>`

.. literalinclude:: ../../../examples/chaco/sine_plot.enaml
    :language: python

.. literalinclude:: ../../../examples/chaco/sine_plot.py
    :language: python

::

 $ python sine_plot.py

.. image:: images/chaco_sine_plot.png

